==> estateplat-common-1.1.0-20160818.121333-155-sources.jar: cn/gtmap/estateplat/model/server/core/BdcXtOpinion.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;

/**
 * 不动产系统意见配置
 * Created by lst on 2015/4/15
 */
@Table(name = "bdc_xt_opinion")
public class BdcXtOpinion {
    @Id
    private String opinid;//意见id
    private String workflowid;//工作流ID
    private String workflowname;//工作流名称
    private String userid;//创建用户Id
    private String isuse;//是否可用
    private String activitytype;//节点名称
    private String isrightclick;//是否右击
    private String content;//是否右击

    public String getOpinid() {
        return opinid;
    }

    public void setOpinid(String opinid) {
        this.opinid = opinid;
    }

    public String getWorkflowid() {
        return workflowid;
    }

    public void setWorkflowid(String workflowid) {
        this.workflowid = workflowid;
    }

    public String getWorkflowname() {
        return workflowname;
    }

    public void setWorkflowname(String workflowname) {
        this.workflowname = workflowname;
    }

    public String getUserid() {
        return userid;
    }

    public void setUserid(String userid) {
        this.userid = userid;
    }

    public String getIsuse() {
        return isuse;
    }

    public void setIsuse(String isuse) {
        this.isuse = isuse;
    }

    public String getActivitytype() {
        return activitytype;
    }

    public void setActivitytype(String activitytype) {
        this.activitytype = activitytype;
    }

    public String getIsrightclick() {
        return isrightclick;
    }

    public void setIsrightclick(String isrightclick) {
        this.isrightclick = isrightclick;
    }

    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }
}

==> estateplat-common-1.2.1-20170628.073448-46-sources.jar: cn/gtmap/estateplat/model/server/core/BdcXtOpinion.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;

/**
 * 不动产系统意见配置
 * Created by lst on 2015/4/15
 */
@Table(name = "bdc_xt_opinion")
public class BdcXtOpinion {
    @Id
    private String opinid;//意见id
    private String workflowid;//工作流ID
    private String workflowname;//工作流名称
    private String userid;//创建用户Id
    private String isuse;//是否可用
    private String activitytype;//节点名称
    private String isrightclick;//是否右击
    private String content;//是否右击
    private String djzxdm;//登记子项代码

    public String getOpinid() {
        return opinid;
    }

    public void setOpinid(String opinid) {
        this.opinid = opinid;
    }

    public String getWorkflowid() {
        return workflowid;
    }

    public void setWorkflowid(String workflowid) {
        this.workflowid = workflowid;
    }

    public String getWorkflowname() {
        return workflowname;
    }

    public void setWorkflowname(String workflowname) {
        this.workflowname = workflowname;
    }

    public String getUserid() {
        return userid;
    }

    public void setUserid(String userid) {
        this.userid = userid;
    }

    public String getIsuse() {
        return isuse;
    }

    public void setIsuse(String isuse) {
        this.isuse = isuse;
    }

    public String getActivitytype() {
        return activitytype;
    }

    public void setActivitytype(String activitytype) {
        this.activitytype = activitytype;
    }

    public String getIsrightclick() {
        return isrightclick;
    }

    public void setIsrightclick(String isrightclick) {
        this.isrightclick = isrightclick;
    }

    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }

    public String getDjzxdm() {
        return djzxdm;
    }

    public void setDjzxdm(String djzxdm) {
        this.djzxdm = djzxdm;
    }
}
